thorn.funtests.base — Thorn 1.3.0 documentation

# thorn.funtests.base

- thorn.funtests.base

## thorn.funtests.base

Extends Cyanide stress test suite with utilities used to test Thorn.

class `thorn.funtests.base.` `WebhookSuite`(app, block_timeout=1800, no_color=False, stdout=None, stderr=None)
  `assert_article_event_received`(article, event, sub=None, reverse=None, ref=None, n=1)
  `assert_log`(ref=None, maxlen=1)
  `assert_log_matches`(log, **expected)
  `assert_ok_pidbox_response`(replies)
  `assert_webhook_not_received`(ref=None)
  `create_article`(title, state=u'PENDING', author=None)
  `delete`(*path, **data)
  `get`(*path, **data)
  `headers`()
  `hook_clear`(event)
  `hook_subscribe`(event, url, callback=None)
  `hook_unsubscribe`(event, url)
  `list_subscriptions`()
  `override_worker_setting`(*args, **kwds)
  `post`(*path, **data)
  `reverse_article`(article)
  `setenv`(setting_name, new_value)
  `setup`()
  `subscribe`(event, ref=None, rest=None)
  `token` = None
  `token_type` = u'Token'
  `unsubscribe`(url)
  `user` = None
  `user2` = None
  `wait_for_webhook_received`(ref=None, maxlen=1)
  `worker_subscribe_to`(*args, **kwds)

`thorn.funtests.base.` `new_ref`()

`thorn.funtests.base.` `url`(*s)

`thorn.funtests.base.` `event_url`(event, ref=None, rest=None)

`thorn.funtests.base.` `testcase`(*groups, **kwargs)